@@ -1133,7 +1133,7 @@ class LaharFlowData(object):
         cols = csv_active_cols(LaharFlowFile)
         return cols
 
-    def _get_data_txt(self, LaharFlowFile):
+    def _get_data_txt(self, LaharFlowFile, var=None):
         try:
             data = pd.read_csv(
                 LaharFlowFile,
@@ -1142,6 +1142,10 @@ class LaharFlowData(object):
                 index_col=["y_distance", "x_distance"],
             )
 
+            if var is not None:
+                drop_vars = [d for d in data.columns if d not in var]
+                data.drop(columns=drop_vars, axis=1, inplace=True)
+
             raster = xa.Dataset.from_dataframe(data)
             raster = raster.rename({"x_distance": "x", "y_distance": "y"})
             raster["x"] = raster["x"] + self.utm[0]
@@ -1152,9 +1156,9 @@ class LaharFlowData(object):
         except:
             raise RuntimeWarning("Unable to get data from {}".format(LaharFlowFile))
 
-    def _get_data_nc(self, LaharFlowFile):
+    def _get_data_nc(self, LaharFlowFile, var=None):
 
-        raster = nc2xr(LaharFlowFile)
+        raster = nc2xr(LaharFlowFile, var=var)
         raster = raster.rename({"x_distance": "x", "y_distance": "y"})
         raster["x"] = raster["x"] + self.utm[0]
         raster["y"] = raster["y"] + self.utm[1]
@@ -1162,7 +1166,7 @@ class LaharFlowData(object):
 
         return raster
 
-    def _get_data(self, filename):
+    def _get_data(self, filename, var=None):
 
         filename = self._valid_input_file(filename)
 
@@ -1171,10 +1175,10 @@ class LaharFlowData(object):
         fileext = os.path.splitext(LaharFlowFile)[1]
 
         if fileext == ".txt":
-            return self._get_data_txt(LaharFlowFile)
+            return self._get_data_txt(LaharFlowFile, var=var)
         elif fileext == ".nc":
             try:
-                d = self._get_data_nc(LaharFlowFile)
+                d = self._get_data_nc(LaharFlowFile, var=var)
             except:
                 print("Could not load netcdf file " + LaharFlowFile)
                 d = None
@@ -1242,12 +1246,22 @@ class LaharFlowData(object):
         filetype = self._file_type(filename)
         filename = self._valid_input_file(filename)
 
-        raster = self._get_data(filename)
+        raster = self._get_data(filename, var=var)
 
-        extra_cols = ["x", "y", "latitude", "longitude"]
+        # if var is not None:
+        #     raster = raster[var]
 
-        if var is not None:
-            raster = raster[var + extra_cols]
+        if crs is not None and crs is not self.utmCode:
+
+            if isinstance(crs, int):
+                crs = "EPSG:" + str(crs)
+                print(crs)
+
+            raster = raster.rio.reproject(
+                dst_crs=crs,
+                resampling=rio.enums.Resampling.cubic,
+                resolution=res,
+            )
 
         return raster
 
@@ -1811,11 +1825,23 @@ class LaharFlowData(object):
 
         return val
 
-    def save_gtiff(self, fileIn, fileOut=None, crs=None, **kwargs):
+    def save_gtiff(self, fileIn, fileOut=None, crs=None, vars=None):
 
         fileIn = self._valid_input_file(fileIn)
 
         raster = self.raster(fileIn)
+        data_vars = raster.data_vars
+
+        if vars is not None:
+            drop_vars = [d for d in data_vars if d not in vars]
+            raster = raster.drop_vars(drop_vars)
+        else:
+            if "tile" in data_vars:
+                raster = raster.drop_vars("tile")
+            if "longitude" in data_vars:
+                raster = raster.drop_vars("longitude")
+            if "latitude" in data_vars:
+                raster = raster.drop_vars("latitude")
 
         if crs is not None:
             if crs != wgs84:
