@@ -9,7 +9,6 @@ from numpy.lib.recfunctions import rename_fields as np_rename_fields
 def nc2xr(filename, var=None):
 
     with nc.Dataset(filename, "r") as rgrp:
-
         attrs = rgrp.__dict__
 
         tiles = list(rgrp.groups)
@@ -17,7 +16,7 @@ def nc2xr(filename, var=None):
 
     if var is not None:
         drop_variables = nc_variables.copy()
-        for v in var:
+        for v in var + ["x", "y"]:
             drop_variables.remove(v)
     else:
         drop_variables = []
